@@ -240,7 +240,12 @@ class GCMT:
     #   Data manipulation
     # ==============================================================================================
     def add_horizontal_average(
-        self, var_key, var_key_out=None, area_key="area_c", tag=None
+        self,
+        var_key,
+        var_key_out=None,
+        part="global",
+        area_key="area_c",
+        tag=None,
     ):
         """
         Calculate horizontal averaged quantities. Horizontal averages
@@ -250,12 +255,22 @@ class GCMT:
 
         Parameters
         ----------
-        var_key: str
-            The key of the variable quantity that should be plotted.
+        var_key: str, xarray.DataArray
+            The key or array of the variable quantity that should be averaged.
+            If str, it will try to look up the key in the dataset.
+            If DataArray, it will use this one instead.
         var_key_out: str, optional
             variable name used to store the outcome.
             If not provided, this script will just
             return the averages and not change the dataset inplace.
+        part: dict or str, optional
+            'global': global average
+            'night': only nightside (defined around +-180,0)
+            'day': only dayside (defined around 0,0)
+            'morning': morning terminator (average around lon=[-100,-80])
+            'evening': evening terminator (average around lon=[80,100])
+            Alternatively you may specify a dict in the following way:
+            part = {'lon': [-100,-80], 'lat':[-90,90]} (example for morn. term.)
         area_key: str, optional
             Variable key in the dataset for the area of grid cells
         tag : str, optional
@@ -271,7 +286,7 @@ class GCMT:
         """
         dsi = self.get_one_model(tag)
         return mani.m_add_horizontal_average(
-            dsi, var_key, var_key_out=var_key_out, area_key=area_key
+            dsi, var_key, var_key_out=var_key_out, part=part, area_key=area_key
         )
 
     def add_rcb(
@@ -280,6 +295,7 @@ class GCMT:
         var_key_out=None,
         area_key="area_c",
         temp_key="T",
+        part="global",
         tag=None,
     ):
         """
@@ -297,6 +313,14 @@ class GCMT:
             variable name used to store the outcome.
             If not provided, this script will just
             return the averages and not change the dataset inplace.
+        part: dict or str, optional
+            'global': global average
+            'night': only nightside (defined around +-180,0)
+            'day': only dayside (defined around 0,0)
+            'morning': morning terminator (average around lon=[-100,-80])
+            'evening': evening terminator (average around lon=[80,100])
+            Alternatively you may specify a dict in the following way:
+            part = {'lon': [-100,-80], 'lat':[-90,90]} (example for morn. term.)
         area_key: str, optional
             Variable key in the dataset for the area of grid cells
         temp_key: str, optional
@@ -317,6 +341,7 @@ class GCMT:
             dsi,
             tol=tol,
             var_key_out=var_key_out,
+            part=part,
             area_key=area_key,
             temp_key=temp_key,
         )
